@@ -18,6 +18,9 @@
 # along with epstopng; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import sys, os
+sys.path.insert(0, "%s/.." % (os.path.dirname(__file__) or "."))
+
 from optparse import OptionParser
 from pyx import *
 from pyx import bbox, version
@@ -47,10 +50,10 @@ while 1:
     if not dvipage:
         break
     if options.paperformat:
-        aligntrafo = trafo.translate(-unit.t_inch, unit.t_inch + paperformat.height)
+        aligntrafo = trafo.translate(unit.t_inch, -unit.t_inch + options.paperformat.height)
         aligneddvipage = canvas.canvas([aligntrafo])
         aligneddvipage.insert(dvipage)
-        p = document.page(aligneddvipage, paperformat=paperformat)
+        p = document.page(aligneddvipage, paperformat=options.paperformat, centered=0)
     else:
         p = document.page(dvipage)
     d.append(p)
