@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: ISO-8859-1 -*-
+# -*- encoding: utf-8 -*-
 #
 #
-# Copyright (C) 2005 Andr Wobst <wobsta@users.sourceforge.net>
+# Copyright (C) 2005-2011 André Wobst <wobsta@users.sourceforge.net>
 #
-# epstopng is free software; you can redistribute it and/or modify
+# dvitype is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
@@ -19,7 +19,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from optparse import OptionParser
-from pyx import dvifile, version
+from pyx import version
+from pyx.dvi import dvifile
 
 parser = OptionParser(usage="usage: %prog dvi-file",
                       version="%prog " + version.version)
@@ -27,6 +28,6 @@ parser = OptionParser(usage="usage: %prog dvi-file",
 if len(args) != 1:
     parser.error("can process a single dvi-file only")
 
-df = dvifile.dvifile(args[0], dvifile.readfontmap(["psfonts.map"]), 1)
+df = dvifile.DVIfile(args[0], debug=True)
 while df.readpage():
     pass
