@@ -3,9 +3,6 @@
 # While most axes do not have a size parameter, it can be added to
 # any existing axis very easily. For linear axes so called sizedlinear
 # and autosizedlinear axes are defined by PyX already.
-# 
-# Note: The mytuple/lambda construct is currently a work-around to
-# create tuples within the mathtree expression evaluator.
 
 from pyx import *
 
@@ -14,8 +11,7 @@ subaxes = [graph.axis.linear(max=1),
            graph.axis.sizedlinear(size=3, min=0, max=3)]
 
 g = graph.graphxy(width=8, y=graph.axis.split(subaxes=subaxes))
-g.plot([graph.data.file("shift.dat", x=1, y="mktuple(i, $(i+2))",
-                        context={"mktuple": lambda x, y: (x, y), "i": i})
+g.plot([graph.data.file("shift.dat", x=1, y="i, $(i+2)", context={"i": i})
         for i in range(3)], [graph.style.line()])
 g.writeEPSfile("shift")
 g.writePDFfile("shift")
