@@ -1,5 +1,4 @@
 from pyx import *
 g = graph.graphxy(width=8)
 g.plot(graph.data.file("graph.dat", x=1, y=2))
-g.writeEPSfile("graph")
-g.writePDFfile("graph")
+g.writePDFfile()
