@@ -1,9 +1,9 @@
-# -*- coding: ISO-8859-1 -*-
+# -*- encoding: utf-8 -*-
 #
 #
-# Copyright (C) 2002-2006 Jrg Lehmann <joergl@users.sourceforge.net>
+# Copyright (C) 2002-2006 Jörg Lehmann <joergl@users.sourceforge.net>
 # Copyright (C) 2003-2005 Michael Schindler <m-schindler@users.sourceforge.net>
-# Copyright (C) 2002-2006 Andr Wobst <wobsta@users.sourceforge.net>
+# Copyright (C) 2002-2011 André Wobst <wobsta@users.sourceforge.net>
 #
 # This file is part of PyX (http://pyx.sourceforge.net/).
 #
@@ -21,17 +21,8 @@
 # along with PyX; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
-from __future__ import nested_scopes
-
 import math
-from math import cos, sin, tan, acos, pi
-try:
-    from math import radians, degrees
-except ImportError:
-    # fallback implementation for Python 2.1
-    def radians(x): return x*pi/180
-    def degrees(x): return x*180/pi
-
+from math import cos, sin, tan, acos, pi, radians, degrees
 import trafo, unit
 from normpath import NormpathException, normpath, normsubpath, normline_pt, normcurve_pt
 import bbox as bboxmodule
@@ -41,20 +32,6 @@ from normpath import set
 # normpath's invalid is available as an external interface
 from normpath import invalid
 
-try:
-    sum([])
-except NameError:
-    # fallback implementation for Python 2.2 and below
-    def sum(list):
-        return reduce(lambda x, y: x+y, list, 0)
-
-try:
-    enumerate([])
-except NameError:
-    # fallback implementation for Python 2.2 and below
-    def enumerate(list):
-        return zip(xrange(len(list)), list)
-
 # use new style classes when possible
 __metaclass__ = type
 
@@ -327,6 +304,12 @@ class closepath(pathitem):
         file.write("closepath\n")
 
 
+class pdfmoveto_pt(normline_pt):
+
+    def outputPDF(self, file, writer):
+        pass
+
+
 class moveto_pt(pathitem):
 
     """Start a new subpath and set current point to (x_pt, y_pt) (coordinates in pts)"""
@@ -349,6 +332,9 @@ class moveto_pt(pathitem):
     def createnormpath(self, epsilon=_marker):
         if epsilon is _marker:
             return normpath([normsubpath([normline_pt(self.x_pt, self.y_pt, self.x_pt, self.y_pt)])])
+        elif epsilon is None:
+            return normpath([normsubpath([pdfmoveto_pt(self.x_pt, self.y_pt, self.x_pt, self.y_pt)],
+                                         epsilon=epsilon)])
         else:
             return normpath([normsubpath([normline_pt(self.x_pt, self.y_pt, self.x_pt, self.y_pt)],
                                          epsilon=epsilon)])
@@ -414,9 +400,9 @@ class curveto_pt(pathitem):
         self.y3_pt = y3_pt
 
     def __str__(self):
-        return "curveto_pt(%g,%g, %g, %g, %g, %g)" % (self.x1_pt, self.y1_pt,
-                                                      self.x2_pt, self.y2_pt,
-                                                      self.x3_pt, self.y3_pt)
+        return "curveto_pt(%g, %g, %g, %g, %g, %g)" % (self.x1_pt, self.y1_pt,
+                                                       self.x2_pt, self.y2_pt,
+                                                       self.x3_pt, self.y3_pt)
 
     def updatebbox(self, bbox, context):
         xmin_pt, xmax_pt = _bezierpolyrange(context.x_pt, self.x1_pt, self.x2_pt, self.x3_pt)
@@ -914,11 +900,11 @@ class multicurveto_pt(pathitem):
 
     def updatebbox(self, bbox, context):
         for point_pt in self.points_pt:
-            bbox.includepoint_pt(*point_pt[0: 2])
-            bbox.includepoint_pt(*point_pt[2: 4])
-            bbox.includepoint_pt(*point_pt[4: 6])
-        if self.points_pt:
-            context.x_pt, context.y_pt = self.points_pt[-1][4:]
+            xmin_pt, xmax_pt = _bezierpolyrange(context.x_pt, point_pt[0], point_pt[2], point_pt[4])
+            ymin_pt, ymax_pt = _bezierpolyrange(context.y_pt, point_pt[1], point_pt[3], point_pt[5])
+            bbox.includepoint_pt(xmin_pt, ymin_pt)
+            bbox.includepoint_pt(xmax_pt, ymax_pt)
+            context.x_pt, context.y_pt = point_pt[4:]
 
     def updatenormpath(self, normpath, context):
         x0_pt, y0_pt = context.x_pt, context.y_pt
@@ -1147,7 +1133,7 @@ class path:
         """split normpath at param(s) or arc length(s) and return list of normpaths"""
         return self.normpath().split(params)
 
-    def tangent_pt(self, params, length=None):
+    def tangent_pt(self, params, length):
         """return tangent vector of path at param(s) or arc length(s) in pts
 
         If length in pts is not None, the tangent vector will be scaled to
@@ -1155,7 +1141,7 @@ class path:
         """
         return self.normpath().tangent_pt(params, length)
 
-    def tangent(self, params, length=None):
+    def tangent(self, params, length=1):
         """return tangent vector of path at param(s) or arc length(s)
 
         If length is not None, the tangent vector will be scaled to
